import Flutter
import UIKit
import Appier

public class SwiftAppierFlutterPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(
      name: "appier_flutter",
      binaryMessenger: registrar.messenger())
    let instance = SwiftAppierFlutterPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

public func handle(_ call: FlutterMethodCall, result: FlutterResult) {

    let arguments:[String:Any] = call.arguments as! [String:Any]
    print(arguments)
    switch call.method {
      case "configure":
        let appId:String? = arguments["appId"] as? String
        let appGroup:String? = arguments["appGroup"] as? String
        let isDev:Bool? = arguments["isDev"] as? Bool
        let valueAppId:String = appId ?? ""
        let valueAppGroup:String? = appGroup
        let valueIsDev:Bool = isDev ?? false
        QGSdk.getSharedInstance().onStart(valueAppId,
          withAppGroup: valueAppGroup,
          setDevProfile: valueIsDev)
        result(nil)
        break
      case "logEvent":
        let name:String? = arguments["eventName"] as? String
        let parameters:[String : Any]? = arguments["parameters"] as? [String:Any]
        let vts:NSNumber? = arguments["vts"] as? NSNumber
        let vtsCurr:String? = arguments["vtsCurr"] as? String
        let valueName:String = name ?? ""
        let valueParameters:[String : Any] = parameters ?? [:]
        let valueVts:NSNumber? = vts
        let valueVtsCurr:String? = vtsCurr
        QGSdk.getSharedInstance().logEvent(valueName, 
            withParameters: valueParameters, 
            withValueToSum: valueVts, 
            withValueToSumCurrency: valueVtsCurr)
        result(nil)
        break
      case "setUniversalLinkDomains":
        if let linkDomains:[String] = arguments["linkDomains"] as? [String], linkDomains.count > 0 {
          QGSdk.getSharedInstance().setUniversalLinkDomains(linkDomains)
        } else {
          print("linkDomains should not be nil or empty array")
        }
        result(nil)
        break
      case "flush":
        QGSdk.getSharedInstance().flush()
        result(nil)
        break
      case "setUserId":
        if let userId:String = arguments["userId"] as? String, userId.count > 0 {
          QGSdk.getSharedInstance().setUserId(userId)
        } else {
          print("Appier: userId should not be nil or empty")
        }
        result(nil)
        break
      case "setName":
        if let name:String = arguments["name"] as? String, name.count > 0 {
          QGSdk.getSharedInstance().setName(name)
        } else {
          print("Appier: name should not be nil or empty")
        }
        result(nil)
        break
      case "setFirstName":
        if let firstName:String = arguments["firstName"] as? String, firstName.count > 0 {
          QGSdk.getSharedInstance().setFirstName(firstName)
        } else {
          print("Appier: firstName should not be nil or empty")
        }
        result(nil)
        break
      case "setLastName":
        if let lastName:String = arguments["lastName"] as? String, lastName.count > 0 {
          QGSdk.getSharedInstance().setLastName(lastName)
        } else {
          print("Appier: lastName should not be nil or empty")
        }
        result(nil)
        break
      case "setCity":
        if let city:String = arguments["city"] as? String, city.count > 0 {
          QGSdk.getSharedInstance().setCity(city)
        } else {
          print("Appier: city should not be nil or empty")
        }
        result(nil)
        break
      case "setEmail":
        if let email:String = arguments["email"] as? String, email.count > 0 {
          QGSdk.getSharedInstance().setEmail(email)
        } else {
          print("Appier: email should not be nil or empty")
        }
        result(nil)
        break
      case "setPhoneNumber":
        if let phoneNo:String = arguments["phoneNo"] as? String, phoneNo.count > 0 {
          QGSdk.getSharedInstance().setCustomKey("phoneNo", withValue:phoneNo)
        } else {
          print("Appier: phoneNo should not be nil or empty")
        }
        result(nil)
        break
      case "setDayOfBirth":
        if let day:NSNumber = arguments["day"] as? NSNumber, day.intValue > 0 {
          QGSdk.getSharedInstance().setDayOfBirth(day)
        } else {
          print("Appier: dayOfBirth should not be nil or zero")
        }
        result(nil)
        break
      case "setMonthOfBirth":
        if let month:NSNumber = arguments["month"] as? NSNumber, month.intValue > 0 {
          QGSdk.getSharedInstance().setMonthOfBirth(month)
        } else {
          print("Appier: monthOfBirth should not be nil or zero")
        }
        result(nil)
        break
      case "setYearOfBirth":
        if let year:NSNumber = arguments["year"] as? NSNumber, year.intValue > 0 {
          QGSdk.getSharedInstance().setMonthOfBirth(year)
        } else {
          print("Appier: yearOfBirth should not be nil or zero")
        }
        result(nil)
        break
      case "setCustomKey":
        if let key:String = arguments["key"] as? String, key.count > 0, let value:Any = arguments["value"] {
          QGSdk.getSharedInstance().setCustomKey(key, withValue:value)
        } else {
          print("Appier: key should not be nil or empty. value shoule not be nil")
        }
        result(nil)
        break
      case "setAttributionWindow":
        if let seconds:Int = arguments["seconds"] as? Int, seconds > 0 {
          QGSdk.getSharedInstance().setAttributionWindow(seconds)
        } else {
          print("Appier: value of AttributionWindow should not be nil or zero")
        }
        result(nil)
        break
      case "setClickAttributionWindow":
        if let seconds:Int = arguments["seconds"] as? Int, seconds > 0 {
          QGSdk.getSharedInstance().setClickAttributionWindow(seconds)
        } else {
          print("Appier: value of ClickAttributionWindow should not be nil or zero")
        }
        result(nil)
        break
      default:
        result(FlutterMethodNotImplemented)
    }
  }
}
